ga_account_list: Account summary for all accounts available to your user
Description
This is the recommended way to get all your account details for your user, including the web property and View IDs. The $viewId column contains the ID you need for the data fetching functions such as google_analytics.
# NOT RUN {# }# NOT RUN {library(googleAnalyticsR)
ga_auth()
al <- ga_account_list()
al$viewId
## get account summary of GA4 propertiesga_account_list("ga4")
# }