Estimate number of users added to the segment yesterday
ga_remarketing_estimate(remarketingAudience)A remarketing audience object from ga_remarketing_get
Takes the segment definition from a remarketing audiences and runs it against the viewId to see current estimated users
The total audience size is this figure for every membershipDurationDay from yesterday
data.frame
Other managementAPI functions: ga_adwords_list,
ga_adwords, ga_clientid_hash,
ga_experiment_list,
ga_experiment, ga_filter_add,
ga_filter_apply_to_view,
ga_filter_delete,
ga_filter_list,
ga_filter_update_filter_link,
ga_filter_update,
ga_filter_view_list,
ga_filter_view, ga_filter,
ga_goal_add, ga_goal_list,
ga_goal_update, ga_goal,
ga_remarketing_get,
ga_remarketing_list,
ga_segment_list,
ga_unsampled_list,
ga_unsampled